netapp_ontap.models.lun_location API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_location`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunLocationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunLocation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `logical_unit: str GET POST PATCH`

    The base name component of the LUN. Valid in POST and PATCH.
    If properties `name` and `location.logical_unit` are specified in the same request, they must refer to the base name.
    A PATCH that modifies the base name of the LUN is considered a rename operation. The volume logical unit property is read-only and cannot be set in POST or PATCH. Use the `name` property for POST.

    Example: lun1

  `node: Node GET`

    The node field of the lun_location.

  `qtree: Qtree GET POST PATCH`

    The qtree field of the lun_location.

  `storage_availability_zone: StorageAvailabilityZone GET POST`

    The storage_availability_zone field of the lun_location.

  `volume: Volume GET POST PATCH`

    The volume field of the lun_location.